# Python-API-Wrapper

This is a simple api wrapper written in python for the Minecraft Server, bedwarspractice.club. It is part of the Voxyl Network.
This wrapper provides access to all data in the Voxyl API. If there is an error, please contact [FirestarAD](mailto:contact.firestarad@gmail.com?subject=[Voxyl API Wrapper] Bug)